emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] /srv/bzr/emacs/trunk r111618: * net/ange-ftp.el (ange-ftp-


From: Michael Albinus
Subject: [Emacs-diffs] /srv/bzr/emacs/trunk r111618: * net/ange-ftp.el (ange-ftp-skip-msgs): Add another message.
Date: Tue, 29 Jan 2013 09:12:11 +0100
User-agent: Bazaar (2.5.0)

------------------------------------------------------------
revno: 111618
committer: Michael Albinus <address@hidden
branch nick: trunk
timestamp: Tue 2013-01-29 09:12:11 +0100
message:
  * net/ange-ftp.el (ange-ftp-skip-msgs): Add another message.
  
  * net/tramp-sh.el (tramp-sh-handle-start-file-process): Catch
  `suppress'.  Otherwise, `tramp-run-real-handler' might be called
  in `tramp-file-name-handler'.
modified:
  lisp/ChangeLog
  lisp/net/ange-ftp.el
  lisp/net/tramp-sh.el
=== modified file 'lisp/ChangeLog'
--- a/lisp/ChangeLog    2013-01-28 20:00:35 +0000
+++ b/lisp/ChangeLog    2013-01-29 08:12:11 +0000
@@ -1,3 +1,11 @@
+2013-01-29  Michael Albinus  <address@hidden>
+
+       * net/ange-ftp.el (ange-ftp-skip-msgs): Add another message.
+
+       * net/tramp-sh.el (tramp-sh-handle-start-file-process): Catch
+       `suppress'.  Otherwise, `tramp-run-real-handler' might be called
+       in `tramp-file-name-handler'.
+
 2013-01-28  Stefan Monnier  <address@hidden>
 
        * hi-lock.el (hi-lock-unface-buffer): Don't assume `face' is a symbol

=== modified file 'lisp/net/ange-ftp.el'
--- a/lisp/net/ange-ftp.el      2013-01-01 09:11:05 +0000
+++ b/lisp/net/ange-ftp.el      2013-01-29 08:12:11 +0000
@@ -720,6 +720,7 @@
          "^Data connection \\|"
          "^local:\\|^Trying\\|^125 \\|^550-\\|^221 .*oodbye\\|"
           "^500 .*AUTH\\|^KERBEROS\\|"
+          "^500 This security scheme is not implemented\\|"
           "^504 Unknown security mechanism\\|"
          "^530 Please login with USER and PASS\\|" ; non kerberized vsFTPd
          "^534 Kerberos Authentication not enabled\\|"

=== modified file 'lisp/net/tramp-sh.el'
--- a/lisp/net/tramp-sh.el      2013-01-24 09:50:02 +0000
+++ b/lisp/net/tramp-sh.el      2013-01-29 08:12:11 +0000
@@ -2824,40 +2824,43 @@
 
       (with-current-buffer (tramp-get-connection-buffer v)
        (unwind-protect
-           (save-excursion
-             (save-restriction
-               ;; Activate narrowing in order to save BUFFER
-               ;; contents.  Clear also the modification time;
-               ;; otherwise we might be interrupted by
-               ;; `verify-visited-file-modtime'.
-               (let ((buffer-undo-list t)
-                     (buffer-read-only nil)
-                     (mark (point)))
-                 (clear-visited-file-modtime)
-                 (narrow-to-region (point-max) (point-max))
-                 ;; We call `tramp-maybe-open-connection', in order
-                 ;; to cleanup the prompt afterwards.
-                 (tramp-maybe-open-connection v)
-                 (widen)
-                 (delete-region mark (point))
-                 (narrow-to-region (point-max) (point-max))
-                 ;; Now do it.
-                 (if command
-                     ;; Send the command.
-                     (tramp-send-command v command nil t) ; nooutput
-                   ;; Check, whether a pty is associated.
-                   (unless (tramp-compat-process-get
-                            (tramp-get-connection-process v) 'remote-tty)
-                     (tramp-error
-                      v 'file-error
-                      "pty association is not supported for `%s'" name))))
-               (let ((p (tramp-get-connection-process v)))
-                 ;; Set query flag for this process.  We ignore errors,
-                 ;; because the process could have finished already.
-                 (ignore-errors
-                   (tramp-compat-set-process-query-on-exit-flag p t))
-                 ;; Return process.
-                 p)))
+           ;; We catch this event.  Otherwise, `start-process' could
+           ;; be called on the local host.
+           (catch 'suppress
+             (save-excursion
+               (save-restriction
+                 ;; Activate narrowing in order to save BUFFER
+                 ;; contents.  Clear also the modification time;
+                 ;; otherwise we might be interrupted by
+                 ;; `verify-visited-file-modtime'.
+                 (let ((buffer-undo-list t)
+                       (buffer-read-only nil)
+                       (mark (point)))
+                   (clear-visited-file-modtime)
+                   (narrow-to-region (point-max) (point-max))
+                   ;; We call `tramp-maybe-open-connection', in order
+                   ;; to cleanup the prompt afterwards.
+                   (tramp-maybe-open-connection v)
+                   (widen)
+                   (delete-region mark (point))
+                   (narrow-to-region (point-max) (point-max))
+                   ;; Now do it.
+                   (if command
+                       ;; Send the command.
+                       (tramp-send-command v command nil t) ; nooutput
+                     ;; Check, whether a pty is associated.
+                     (unless (tramp-compat-process-get
+                              (tramp-get-connection-process v) 'remote-tty)
+                       (tramp-error
+                        v 'file-error
+                        "pty association is not supported for `%s'" name))))
+                 (let ((p (tramp-get-connection-process v)))
+                   ;; Set query flag for this process.  We ignore errors,
+                   ;; because the process could have finished already.
+                   (ignore-errors
+                     (tramp-compat-set-process-query-on-exit-flag p t))
+                   ;; Return process.
+                   p))))
 
          ;; Save exit.
          (if (string-match tramp-temp-buffer-name (buffer-name))


reply via email to

[Prev in Thread] Current Thread [Next in Thread]